pub struct ModelEscalationConfig {
pub escalation_model: String,
pub escalation_threshold_seconds: i64,
}Expand description
Model-based escalation configuration for routing requests to a different model at claim time when approaching SLA deadline.
When a request is claimed with less than escalation_threshold_seconds remaining
before batch expiry, it will be routed to the escalation_model instead of the
original model. The batch API key automatically has access to escalation models
in the onwards routing cache (no separate API key needed).
Fields
escalation_model: StringThe model to escalate to (e.g., “o1-preview” for requests using “gpt-4”)
escalation_threshold_seconds: i64Time threshold in seconds - escalate when time remaining before batch expiry is less than this value. Default: 900 (15 minutes)