Module http

Module http 

HTTP client abstraction for making requests.

This module defines the HttpClient trait to abstract HTTP request execution, enabling testability with mock implementations.

Structs

HttpResponse
Response from an HTTP request. TODO: How will we deal with streaming responses? Right now we buffer the whole response before writing it back
MockCall
Record of a call made to the mock HTTP client.
MockHttpClient
Mock HTTP client for testing.
ReqwestHttpClient
Production HTTP client using reqwest.

Traits

HttpClient
Trait for executing HTTP requests.

Type Aliases

StreamReassembler
Function signature for stream reassemblers.