Module manager

Module manager 

Main traits for the batching system.

This module defines the Storage and RequestManager traits, which provide the interface for persisting requests, creating files, launching batches, and checking execution status.

Modules

postgres
PostgreSQL implementation of Storage and DaemonExecutor.

Traits

DaemonExecutor
Daemon executor trait for runtime orchestration.
DaemonStorage
Daemon lifecycle persistence.
Storage
Storage trait for persisting and querying requests.