pub trait RequestState: Send + Sync { }Expand description
Marker trait for valid request states.
This trait enables the typestate pattern, ensuring that operations are only performed on requests in valid states.
pub trait RequestState: Send + Sync { }Marker trait for valid request states.
This trait enables the typestate pattern, ensuring that operations are only performed on requests in valid states.