HTTP client abstraction for making requests.
This module defines the HttpClient trait to abstract HTTP request execution,
enabling testability with mock implementations.
Structs
- Http
Response - Response from an HTTP request. TODO: How will we deal with streaming responses? Right now we buffer the whole response before writing it back
- Mock
Call - Record of a call made to the mock HTTP client.
- Mock
Http Client - Mock HTTP client for testing.
- Reqwest
Http Client - Production HTTP client using reqwest.
Traits
- Http
Client - Trait for executing HTTP requests.
Type Aliases
- Stream
Reassembler - Function signature for stream reassemblers.